@@ -892,6 +892,7 @@ make_message(struct dhcp_message **message,
 
 	if (lease->addr.s_addr && lease->cookie == htonl(MAGIC_COOKIE)) {
 		if (type == DHCP_DECLINE ||
+		    type == DHCP_DISCOVER ||
 		    (type == DHCP_REQUEST &&
 			lease->addr.s_addr != iface->addr.s_addr))
 		{
@@ -914,9 +915,6 @@ make_message(struct dhcp_message **message,
 		p += len;
 	}
 
-	if (type == DHCP_DISCOVER && ifo->options & DHCPCD_REQUEST)
-		PUTADDR(DHO_IPADDRESS, ifo->req_addr);
-
 	if (type == DHCP_DISCOVER ||
 	    type == DHCP_INFORM ||
 	    type == DHCP_REQUEST)
@@ -1143,9 +1141,7 @@ print_string(char *s, ssize_t len, int dl, const uint8_t *data)
 		case '\'': /* FALLTHROUGH */
 		case '$':  /* FALLTHROUGH */
 		case '`':  /* FALLTHROUGH */
- 		case '\\': /* FALLTHROUGH */
-		case '|':  /* FALLTHROUGH */
-		case '&':
+ 		case '\\':
 			if (s) {
 				if (len < 3) {
 					errno = ENOBUFS;
