@@ -1,6 +1,6 @@
 /* 
  * dhcpcd - DHCP client daemon
- * Copyright (c) 2006-2011 Roy Marples <roy@marples.name>
+ * Copyright (c) 2006-2010 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -25,7 +25,7 @@
  * SUCH DAMAGE.
  */
 
-const char copyright[] = "Copyright (c) 2006-2011 Roy Marples";
+const char copyright[] = "Copyright (c) 2006-2010 Roy Marples";
 
 #include <sys/file.h>
 #include <sys/socket.h>
@@ -528,17 +528,7 @@ handle_dhcp(struct interface *iface, struct dhcp_message **dhcpp, const struct i
 			log_dhcp(LOG_WARNING, "reject DHCP", iface, dhcp, from);
 			return;
 		}
-	}
-
-	/* Ensure that the address offered is valid */
-	if ((type == 0 || type == DHCP_OFFER || type == DHCP_ACK) &&
-	    (dhcp->ciaddr == INADDR_ANY || dhcp->ciaddr == INADDR_BROADCAST) &&
-	    (dhcp->yiaddr == INADDR_ANY || dhcp->yiaddr == INADDR_BROADCAST))
-	{
-		log_dhcp(LOG_WARNING, "reject invalid address",
-		    iface, dhcp, from);
-		return;
-	}
+	}		
 
 	/* No NAK, so reset the backoff */
 	state->nakoff = 1;
@@ -641,7 +631,7 @@ handle_dhcp_packet(void *arg)
 	const uint8_t *pp;
 	ssize_t bytes;
 	struct in_addr from;
-	int i, partialcsum = 0;
+	int i;
 
 	/* We loop through until our buffer is empty.
 	 * The benefit is that if we get >1 DHCP packet in our buffer and
@@ -649,10 +639,10 @@ handle_dhcp_packet(void *arg)
 	packet = xmalloc(udp_dhcp_len);
 	for(;;) {
 		bytes = get_raw_packet(iface, ETHERTYPE_IP,
-		    packet, udp_dhcp_len, &partialcsum);
+		    packet, udp_dhcp_len);
 		if (bytes == 0 || bytes == -1)
 			break;
-		if (valid_udp_packet(packet, bytes, &from, partialcsum) == -1) {
+		if (valid_udp_packet(packet, bytes, &from) == -1) {
 			syslog(LOG_ERR, "%s: invalid UDP packet from %s",
 			    iface->name, inet_ntoa(from));
 			continue;
@@ -819,23 +809,17 @@ configure_interface1(struct interface *iface)
 	if (ifo->options & DHCPCD_CLIENTID)
 		syslog(LOG_DEBUG, "%s: using ClientID %s", iface->name,
 		    hwaddr_ntoa(iface->clientid + 1, *iface->clientid));
-	else
-		syslog(LOG_DEBUG, "%s: using hwaddr %s", iface->name,
-		    hwaddr_ntoa(iface->hwaddr, iface->hwlen));
 }
 
 int
 select_profile(struct interface *iface, const char *profile)
 {
 	struct if_options *ifo;
-	int ret;
 
-	ret = 0;
 	ifo = read_config(cffile, iface->name, iface->ssid, profile);
 	if (ifo == NULL) {
 		syslog(LOG_DEBUG, "%s: no profile %s", iface->name, profile);
-		ret = -1;
-		goto exit;
+		return -1;
 	}
 	if (profile != NULL) {
 		strlcpy(iface->state->profile, profile,
@@ -846,11 +830,8 @@ select_profile(struct interface *iface, const char *profile)
 		*iface->state->profile = '\0';
 	free_options(iface->state->options);
 	iface->state->options = ifo;
-
-exit:
-	if (profile)
-		configure_interface1(iface);
-	return ret;
+	configure_interface1(iface);
+	return 0;
 }
 
 static void
@@ -860,6 +841,7 @@ start_fallback(void *arg)
 
 	iface = (struct interface *)arg;
 	select_profile(iface, iface->state->options->fallback);
+	configure_interface1(iface);
 	start_interface(iface);
 }
 
@@ -929,11 +911,7 @@ start_discover(void *arg)
 		else
 			add_timeout_sec(ifo->timeout, start_ipv4ll, iface);
 	}
-	if (ifo->options & DHCPCD_REQUEST)
-		syslog(LOG_INFO, "%s: broadcasting for a lease (requesting %s)",
-		    iface->name, inet_ntoa(ifo->req_addr));
-	else
-		syslog(LOG_INFO, "%s: broadcasting for a lease", iface->name);
+	syslog(LOG_INFO, "%s: broadcasting for a lease", iface->name);
 	send_discover(iface);
 }
 
@@ -1121,6 +1099,9 @@ start_interface(void *arg)
 		return;
 	}
 
+	/* We don't want to read the old lease if we NAK an old test */
+	nolease = iface->state->offer && options & DHCPCD_TEST;
+
 	iface->start_uptime = uptime();
 	free(iface->state->offer);
 	iface->state->offer = NULL;
@@ -1145,9 +1126,21 @@ start_interface(void *arg)
 		delete_timeout(NULL, iface);
 		return;
 	}
-	/* We don't want to read the old lease if we NAK an old test */
-	nolease = iface->state->offer && options & DHCPCD_TEST;
-	if (!nolease)
+	if (ifo->req_addr.s_addr) {
+		iface->state->offer =
+		    dhcp_message_new(&ifo->req_addr, &ifo->req_mask);
+		if (ifo->options & DHCPCD_REQUEST)
+			ifo->req_addr.s_addr = 0;
+		else {
+			iface->state->reason = "STATIC";
+			iface->state->new = iface->state->offer;
+			iface->state->offer = NULL;
+			get_lease(&iface->state->lease, iface->state->new);
+			configure(iface);
+			start_inform(iface);
+			return;
+		}
+	} else if (!nolease)
 		iface->state->offer = read_lease(iface);
 	if (iface->state->offer) {
 		get_lease(&iface->state->lease, iface->state->offer);
@@ -1206,10 +1199,6 @@ init_state(struct interface *iface, int argc, char **argv)
 	configure_interface(iface, argc, argv);
 	if (!(options & DHCPCD_TEST))
 		run_script(iface);
-	/* We need to drop the leasefile so that start_interface
-	 * doesn't load it. */	
-	if (ifs->options->options & DHCPCD_REQUEST)
-		unlink(iface->leasefile);
 
 	if (ifs->options->options & DHCPCD_LINK) {
 		switch (carrier_status(iface)) {
@@ -1284,43 +1273,6 @@ handle_interface(int action, const char *ifname)
 	}
 }
 
-#ifdef RTM_CHGADDR
-void
-handle_hwaddr(const char *ifname, unsigned char *hwaddr, size_t hwlen)
-{
-	struct interface *ifp;
-	struct if_options *ifo;
-
-	for (ifp = ifaces; ifp; ifp = ifp->next)
-		if (strcmp(ifp->name, ifname) == 0 && ifp->hwlen <= hwlen) {
-			ifo = ifp->state->options;
-			if (!(ifo->options &
-			    (DHCPCD_INFORM | DHCPCD_STATIC | DHCPCD_CLIENTID))
-	    		    && ifp->state->new != NULL &&
-			    ifp->state->new->cookie == htonl(MAGIC_COOKIE))
-			{
-				syslog(LOG_INFO,
-				    "%s: expiring for new hardware address",
-				    ifp->name);
-				drop_config(ifp, "EXPIRE");
-			}
-			memcpy(ifp->hwaddr, hwaddr, hwlen);
-			ifp->hwlen = hwlen;
-			if (!(ifo->options &
-			    (DHCPCD_INFORM | DHCPCD_STATIC | DHCPCD_CLIENTID)))
-			{
-				syslog(LOG_DEBUG, "%s: using hwaddr %s",
-				    ifp->name,
-		    		    hwaddr_ntoa(ifp->hwaddr, ifp->hwlen));
-				ifp->state->interval = 0;
-				ifp->state->nakoff = 1;
-				start_interface(ifp);
-			}
-		}
-	free(hwaddr);
-}
-#endif
-
 void
 handle_ifa(int type, const char *ifname,
     struct in_addr *addr, struct in_addr *net, struct in_addr *dst)
@@ -1688,8 +1640,7 @@ open_sockets(struct interface *iface)
 	if (iface->udp_fd == -1 &&
 	    iface->addr.s_addr != 0 &&
 	    iface->state->new != NULL &&
-	    (iface->state->new->cookie == htonl(MAGIC_COOKIE) ||
-	    iface->state->options->options & DHCPCD_INFORM))
+	    iface->state->new->cookie == htonl(MAGIC_COOKIE))
 	{
 		if (open_udp_socket(iface) == -1 && errno != EADDRINUSE)
 			syslog(LOG_ERR, "%s: open_udp_socket: %m", iface->name);
@@ -2025,20 +1976,17 @@ main(int argc, char **argv)
 				}
 			}
 		}
-		if (options & DHCPCD_MASTER)
-			i = if_options->timeout;
-		else
-			i = ifaces->state->options->timeout;
 		if (opt == 0 &&
 		    options & DHCPCD_LINK &&
 		    !(options & DHCPCD_WAITIP))
 		{
 			syslog(LOG_WARNING, "no interfaces have a carrier");
 			daemonise();
-		} else if (i > 0) {
+		} else if (if_options->timeout > 0) {
 			if (options & DHCPCD_IPV4LL)
 				options |= DHCPCD_TIMEOUT_IPV4LL;
-			add_timeout_sec(i, handle_exit_timeout, NULL);
+			add_timeout_sec(if_options->timeout,
+			    handle_exit_timeout, NULL);
 		}
 	}
 	free_options(if_options);
