@@ -1,6 +1,6 @@
 /* 
  * dhcpcd - DHCP client daemon
- * Copyright (c) 2006-2010 Roy Marples <roy@marples.name>
+ * Copyright (c) 2006-2008 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -223,6 +223,16 @@ delete_q_timeouts(int queue, void *arg, void (*callback)(void *), ...)
 	va_end(va);
 }
 
+void
+delete_timeouts( void *arg, void (*callback)(void *), ...)
+{
+	va_list va;
+
+	va_start(va, callback);
+	v_delete_q_timeouts(0, arg, callback, va);
+	va_end(va);
+}
+
 void
 delete_q_timeout(int queue, void (*callback)(void *), void *arg)
 {
